==> dojo-1.9.4.tgz: package/cldr/nls/ko/generic.js <==
define(
//begin v1.x content
{
	"dateFormatItem-yyyyMMMEd": "G y년 MMM d일 (E)",
	"field-dayperiod": "오전/오후",
	"field-minute": "분",
	"dateFormatItem-MMMEd": "MMM d일 (E)",
	"dateTimeFormat-full": "{1} {0}",
	"field-day-relative+-1": "어제",
	"dateFormatItem-hms": "a h:mm:ss",
	"field-day-relative+-2": "그저께",
	"field-weekday": "요일",
	"dateFormatItem-MMM": "LLL",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-Gy": "G y년",
	"dateTimeFormat-medium": "{1} {0}",
	"field-era": "연호",
	"field-hour": "시",
	"dateFormatItem-y": "G y년",
	"dateFormatItem-yyyy": "G y년",
	"dateFormatItem-yyyyMMMEEEEd": "G y년 MMM d일 EEEE",
	"dateFormatItem-EEEEd": "d일 EEEE",
	"dateFormatItem-Ed": "d일 (E)",
	"field-day-relative+0": "오늘",
	"field-day-relative+1": "내일",
	"field-day-relative+2": "모레",
	"dateFormatItem-GyMMMd": "G y년 MMM d일",
	"dateFormat-long": "G y년 M월 d일",
	"field-zone": "시간대",
	"dateFormatItem-Hm": "HH:mm",
	"dateFormatItem-MMMEEEEd": "MMM d일 EEEE",
	"field-week-relative+-1": "지난주",
	"dateFormat-medium": "G y. M. d.",
	"dateFormatItem-Hms": "H시 m분 s초",
	"field-year-relative+0": "올해",
	"field-year-relative+1": "내년",
	"field-year-relative+-1": "지난해",
	"dateFormatItem-ms": "mm:ss",
	"dateFormatItem-yyyyQQQQ": "G y년 QQQQ",
	"field-year": "년",
	"dateFormatItem-GyMMMEEEEd": "G y년 MMM d일 EEEE",
	"dateTimeFormat-long": "{1} {0}",
	"dateFormatItem-HHmmss": "HH:mm:ss",
	"field-week": "주",
	"dateFormatItem-yyyyMd": "G y. M. d.",
	"dateFormatItem-yyyyMMMd": "G y년 MMM d일",
	"dateFormatItem-yyyyMEd": "G y. M. d. (E)",
	"dateFormatItem-yyyyMEEEEd": "G y. M. d. EEEE",
	"dateFormatItem-MMMd": "MMM d일",
	"field-week-relative+0": "이번 주",
	"field-week-relative+1": "다음 주",
	"field-month-relative+0": "이번 달",
	"dateFormatItem-H": "H시",
	"field-month": "월",
	"field-month-relative+1": "다음 달",
	"dateFormatItem-M": "M월",
	"field-second": "초",
	"dateFormatItem-GyMMMEd": "G y년 MMM d일 (E)",
	"dateFormatItem-GyMMM": "G y년 MMM",
	"dateFormatItem-MEEEEd": "M. d. EEEE",
	"field-day": "일",
	"dateFormatItem-MEd": "M. d. (E)",
	"dateFormatItem-yyyyQQQ": "G y년 QQQ",
	"dateFormatItem-hm": "a h:mm",
	"dateFormat-short": "G y. M. d.",
	"dateFormatItem-yyyyM": "G y. M.",
	"dateFormat-full": "G y년 M월 d일 EEEE",
	"dateFormatItem-Md": "M. d.",
	"dateFormatItem-yyyyMMM": "G y년 MMM",
	"dateFormatItem-d": "d일",
	"field-month-relative+-1": "지난달",
	"dateFormatItem-h": "a h시"
}
//end v1.x content
);

==> dojo-1.13.5.tgz: package/cldr/nls/ko/generic.js <==
define(
//begin v1.x content
{
	"field-second-relative+0": "지금",
	"field-weekday": "요일",
	"field-wed-relative+0": "이번 수요일",
	"dateFormatItem-GyMMMEd": "G y년 MMM d일 (E)",
	"dateFormatItem-MMMEd": "MMM d일 (E)",
	"field-wed-relative+1": "다음 수요일",
	"field-tue-relative+-1": "지난 화요일",
	"dateFormat-long": "G y년 M월 d일",
	"field-fri-relative+-1": "지난 금요일",
	"field-wed-relative+-1": "지난 수요일",
	"dateFormatItem-yyyyQQQ": "G y년 QQQ",
	"dateTimeFormat-medium": "{1} {0}",
	"dateFormat-full": "G y년 M월 d일 EEEE",
	"dateFormatItem-yyyyMEd": "G y. M. d. (E)",
	"field-thu-relative+-1": "지난 목요일",
	"dateFormatItem-Md": "M. d.",
	"field-era": "연호",
	"dateFormatItem-MEEEEd": "M. d. EEEE",
	"field-year": "년",
	"field-hour": "시",
	"field-sat-relative+0": "이번 토요일",
	"field-sat-relative+1": "다음 토요일",
	"field-day-relative+0": "오늘",
	"field-day-relative+1": "내일",
	"field-thu-relative+0": "이번 목요일",
	"dateFormatItem-GyMMMd": "G y년 MMM d일",
	"field-day-relative+2": "모레",
	"field-thu-relative+1": "다음 목요일",
	"dateFormatItem-H": "H시",
	"dateFormatItem-Gy": "G y년",
	"dateFormatItem-HHmmss": "HH:mm:ss",
	"dateFormatItem-yyyyMMMEd": "G y년 MMM d일 (E)",
	"dateFormatItem-M": "M월",
	"dateFormatItem-yyyyMMM": "G y년 MMM",
	"dateFormatItem-yyyyMMMd": "G y년 MMM d일",
	"field-sun-relative+0": "이번 일요일",
	"dateFormatItem-Hm": "HH:mm",
	"field-sun-relative+1": "다음 일요일",
	"field-minute": "분",
	"field-dayperiod": "오전/오후",
	"dateFormatItem-d": "d일",
	"dateFormatItem-yyyyMEEEEd": "G y. M. d. EEEE",
	"dateFormatItem-ms": "mm:ss",
	"field-day-relative+-1": "어제",
	"dateFormatItem-h": "a h시",
	"dateTimeFormat-long": "{1} {0}",
	"field-day-relative+-2": "그저께",
	"dateFormatItem-MMMd": "MMM d일",
	"dateFormatItem-EEEEd": "d일 EEEE",
	"dateFormatItem-MEd": "M. d. (E)",
	"dateTimeFormat-full": "{1} {0}",
	"field-fri-relative+0": "이번 금요일",
	"field-fri-relative+1": "다음 금요일",
	"field-day": "일",
	"field-zone": "시간대",
	"dateFormatItem-y": "G y년",
	"field-year-relative+-1": "작년",
	"field-month-relative+-1": "지난달",
	"dateFormatItem-hm": "a h:mm",
	"dateFormatItem-GyMMMEEEEd": "G y년 MMM d일 EEEE",
	"dateFormatItem-yyyyMMMEEEEd": "G y년 MMM d일 EEEE",
	"dateFormatItem-MMMEEEEd": "MMM d일 EEEE",
	"dateFormatItem-yyyyMd": "G y. M. d.",
	"field-month": "월",
	"dateFormatItem-MMM": "LLL",
	"field-tue-relative+0": "이번 화요일",
	"field-tue-relative+1": "다음 화요일",
	"field-mon-relative+0": "이번 월요일",
	"field-mon-relative+1": "다음 월요일",
	"dateFormat-short": "G y. M. d.",
	"field-second": "초",
	"field-sat-relative+-1": "지난 토요일",
	"field-sun-relative+-1": "지난 일요일",
	"field-month-relative+0": "이번 달",
	"field-month-relative+1": "다음 달",
	"dateFormatItem-Ed": "d일 (E)",
	"field-week": "주",
	"dateFormat-medium": "G y. M. d.",
	"field-year-relative+0": "올해",
	"field-week-relative+-1": "지난주",
	"dateFormatItem-yyyyM": "G y. M.",
	"field-year-relative+1": "내년",
	"dateFormatItem-yyyyQQQQ": "G y년 QQQQ",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-Hms": "H시 m분 s초",
	"dateFormatItem-hms": "a h:mm:ss",
	"dateFormatItem-GyMMM": "G y년 MMM",
	"field-mon-relative+-1": "지난 월요일",
	"dateFormatItem-yyyy": "G y년",
	"field-week-relative+0": "이번 주",
	"field-week-relative+1": "다음 주"
}
//end v1.x content
);
